# SuperRPA

## 介绍
二次封装 Selenium，并且搭载各种文本、csv、xlsx、本地文件等操作。后期会不断更新新功能。谢谢使用 ~

## 安装教程

1.  pip install SuperRPA

## 使用说明

1.  from Super_PyPackage import py_selenium
2.  看源码。

## 与作者互动

* **Email**：yelang97@qq.com
* **pypi地址**：https://pypi.org/project/SuperRPA/
* **了解作者更多，请查看csdn博客**：https://blog.csdn.net/weixin_42038955
* **gitee地址**：https://gitee.com/xiaoye_01/super-rpa
* **您的使用，是我最大的动力，支持开源。**
